SyncActuatorState

Trait SyncActuatorState 

pub trait SyncActuatorState<U: UnitSet = Rotary> {
    // Required methods
    fn pos(&self) -> U::Position;
    fn moving(&self) -> bool;
    fn halt(&self);
    fn interrupt(&self);
}
The state of a SyncActuator is used to control the component while it is moving and to get data about the current movement

Required Methods

fn pos(&self) -> U::Position

Returns the current absolute position of the actuator

fn moving(&self) -> bool

Returns whether the actuator is currently moving or not

fn halt(&self)

Halt the actuator

fn interrupt(&self)

Interrupt the movement of the actuator

Implementors