pub enum ActuatorError<U: UnitSet = Rotary> {
InvaldRelativeDistance(U::Distance),
InvalidVelocity(U::Velocity),
VelocityTooHigh(U::Velocity, U::Velocity),
InvalidAcceleration(U::Acceleration),
InvalidJolt(U::Jolt),
InvalidTime(U::Time),
IOError,
Overload,
}Expand description
General Error type for SyncActuators
Variants
InvaldRelativeDistance(U::Distance)
The rel_dist distance given is invalid
InvalidVelocity(U::Velocity)
The velocity given is invalid somehow, depending on the context (see the function description)
VelocityTooHigh(U::Velocity, U::Velocity)
The velocity given is too high, depending on the context, see the function description
- 0: [U::Velocity] - The given velocity
- 1: [U::Velocity] - The maximum velocity
InvalidAcceleration(U::Acceleration)
The [Acceleration] given is invalid somehow, depending on the context (see the function description)
InvalidJolt(U::Jolt)
The Jolt given is invalid somehow, depending on the context (see the function description)
InvalidTime(U::Time)
The Time given is invalid somehow, depending on the context, see the function description
IOError
Something is wrong with the IO connections of the actuator (PINs etc.)
Overload
The component has been overloaded