pub trait SyncActuatorState<U: UnitSet = Rotary> {
// Required methods
fn pos(&self) -> U::Position;
fn moving(&self) -> bool;
fn halt(&self);
fn interrupt(&self);
}Expand description
The state of a SyncActuator is used to control the component while it is moving and to get data about the current movement